@@ -2,15 +2,15 @@
 #' Packages exporting a function 
 #' 
 #' @description 
-#' \code{get_all_pkgs} provides all installed packages exported by a given 
-#' function.
+#' \code{get_all_pkgs} provides all packages (belonging to a given list of 
+#' packages) exported by a given function.
 #' 
 #' @param fun
 #' function or character. The function of interest.
 #' 
 #' @param packages
-#' The packages to look into. If \code{NULL}, the whole list of installed 
-#' packages is explorered. 
+#' The packages to look into. If \code{NULL}, the list of currently attached  
+#' packages is explored. 
 #' 
 #' @return 
 #' A character vector, the packages. 
@@ -18,9 +18,11 @@
 #' @export
 #' 
 #' @examples 
+#' \dontrun{
 #' get_all_pkgs("as.fun")
 #' get_all_pkgs(as.fun)
 #' get_all_pkgs("stats::median")
+#' }
 #' 
 get_all_pkgs <- 
 function(fun, 
@@ -32,11 +34,14 @@ function(fun,
   }
   
   fun <- fun[1L]
-  if (grepl("::", fun)) {
+  if (grepl(":::", fun)) {
+    parts <- strsplit(fun, ":::")[[1L]]
+    pkgs <- parts[1L]
+  } else if (grepl("::", fun)) {
     parts <- strsplit(fun, "::")[[1L]]
     pkgs <- parts[1L]
   } else {
-    if (is.null(packages)) packages <- .packages(all.available = TRUE)
+    if (is.null(packages)) packages <- .packages(all.available = FALSE)
     w <- which(vapply(packages, 
                       FUN = function(pkg) { fun %in% get_all_funs(pkg) }, 
                       FUN.VALUE = logical(1L)))
